@@ -12,8 +12,9 @@ class ProjectConfig(IConfig):
     )
 
     def __init__(self):
-        self.project_name = None
-        self.data_dir = None
+        self.project_name: str = None
+        self.data_dir: str = None
+        self.global_export_dir: str = None
         self.plugin_configs = dict()
 
     @property
@@ -29,6 +30,7 @@ class ProjectConfig(IConfig):
         return {
             "project_name": obj.project_name,
             "data_dir": obj.data_dir,
+            "global_export_dir": obj.global_export_dir,
             "plugin_configs": obj.plugin_configs
         }
 
@@ -40,6 +42,7 @@ class ProjectConfig(IConfig):
         obj = ProjectConfig()
         obj.project_name = dic["project_name"]
         obj.data_dir = dic["data_dir"]
+        obj.global_export_dir = dic["global_export_dir"]
         obj.plugin_configs = dic["plugin_configs"]
 
         return obj
