@@ -3,6 +3,7 @@ from rigger_singleton.singleton import singleton
 from data2code_sdk.config.project_config import ProjectConfig
 from typing import List
 from data2code_sdk.plugin.output_data import OutputData
+from data2code_sdk.plugin.interface_plugin import IPlugin
 
 
 @singleton
@@ -76,6 +77,25 @@ class AppStartSignal(Signal):
     pass
 
 
+@singleton
+class RequestToInstallPluginSignal(Signal):
+    """
+    请求安装指定插件
+    """
+    def dispatch(self, path: str):
+        super().dispatch(path)
+
+
+@singleton
+class PluginInfoUpdateSignal(Signal):
+    """
+    插件信息更新的信号
+    会传送当前所有的插件信息
+    """
+    def dispatch(self, plugin_classes: List, plugin_instances: List[IPlugin]):
+        super().dispatch(plugin_classes, plugin_instances)
+
+
 @singleton
 class LackOfNecessaryPlugin(Signal):
     """
